dnl These are slightly modified version of the default test for f77

dnl Determine a Fortran 90 compiler to use.  If `F90' is not already set
dnl in the environment, check for `f95', `f90' and `pgf90', in that order.
dnl Set the output variable `F90' to the name of the compiler found.
dnl 
dnl AC_PROG_F90()
AC_DEFUN(AC_PROG_F90,
[AC_BEFORE([$0], [AC_PROG_CPP])dnl
if test -z "$F90"; then
  AC_PATH_PROGS(F90, f95 f90 pgf90)
  test -z "$F90" && AC_MSG_ERROR([no acceptable Fortran 90 compiler found in \$PATH])
fi
AC_PROG_F90_WORKS
])

dnl Test whether the Fortran 90 compiler can compile and link a trivial
dnl Fortran program.  Also, test whether the Fortran 90 compiler is a
dnl cross-compiler.
dnl 
dnl AC_PROG_F90_WORKS()
AC_DEFUN(AC_PROG_F90_WORKS,
[AC_MSG_CHECKING([whether the Fortran 90 compiler ($F90 $F90FLAGS $LDFLAGS) works])
AC_LANG_SAVE
AC_LANG_FORTRAN90
AC_TRY_COMPILER_NOINCLUDE(dnl
[program conftest
end program conftest
], ac_cv_prog_f90_works, ac_cv_prog_f90_cross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_f90_works)

if test $ac_cv_prog_f90_works = no; then
  AC_MSG_ERROR([installation or configuration problem: Fortran 90 compiler cannot create executables.])
fi

AC_MSG_CHECKING([whether this compiler is a cross-compiler])
AC_MSG_RESULT($ac_cv_prog_f90_cross)
cross_compiling=$ac_cv_prog_f90_cross

AC_MSG_CHECKING([whether this compiler permits quadruple precision])
AC_LANG_SAVE
AC_LANG_FORTRAN90
AC_TRY_COMPILER_NOINCLUDE(dnl
[program conftest
integer, parameter :: d=selected_real_kind(precision(1.)+1, range(1.)+1)
integer, parameter :: q=selected_real_kind(precision(1._d)+1, range(1._d))
real(kind=q) :: x
end program conftest
], ac_cv_prog_f90_quadra, ac_cv_prog_f90_cross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_f90_quadra)

AC_MSG_CHECKING([whether this compiler permits quadruple complex])
AC_LANG_SAVE
AC_LANG_FORTRAN90
AC_TRY_COMPILER_NOINCLUDE(dnl
[program conftest
integer, parameter :: d=selected_real_kind(precision(1.)+1, range(1.)+1)
integer, parameter :: q=selected_real_kind(precision(1._d)+1, range(1._d))
complex(kind=q) :: x
end program conftest
], ac_cv_prog_f90_qcomplex, ac_cv_prog_f90_qcross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_f90_qcomplex)

AC_MSG_CHECKING([whether this compiler accepts PURE functions])
AC_LANG_SAVE
AC_LANG_FORTRAN90
AC_TRY_COMPILER_NOINCLUDE(dnl
[program conftest
contains
  pure function f(x)
    real, intent(in) :: x
    real :: f
    f = x
  end function f
end program conftest
], ac_cv_prog_f90_pure, ac_cv_prog_f90_cross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_f90_pure)

])


dnl AC_LANG_FORTRAN90()
AC_DEFUN(AC_LANG_FORTRAN90,
[define([AC_LANG], [FORTRAN90])dnl
ac_ext=f90
ac_compile='${F90-f90} -c $F90FLAGS conftest.$ac_ext 1>&AC_FD_CC'
ac_link='${F90-f90} -o conftest${ac_exeext} $F90FLAGS $LDFLAGS conftest.$ac_ext $LIBS 1>&AC_FD_CC'
cross_compiling=$ac_cv_prog_f90_cross
])

dnl Try to compile, link and execute TEST-PROGRAM.  Set WORKING-VAR to
dnl `yes' if the current compiler works, otherwise set it ti `no'.  Set
dnl CROSS-VAR to `yes' if the compiler and linker produce non-native
dnl executables, otherwise set it to `no'.  Before calling
dnl `AC_TRY_COMPILER()', call `AC_LANG_*' to set-up for the right
dnl language.
dnl
dnl Changes: do not include an #include line
dnl 
dnl AC_TRY_COMPILER_NOINCLUDE(TEST-PROGRAM, WORKING-VAR, CROSS-VAR)
AC_DEFUN(AC_TRY_COMPILER_NOINCLUDE,
[cat > conftest.$ac_ext << EOF
[$1]
EOF
if AC_TRY_EVAL(ac_link) && test -s conftest${ac_exeext}; then
  [$2]=yes
  # If we can't run a trivial program, we are probably using a cross compiler.
  if (./conftest; exit) 2>/dev/null; then
    [$3]=no
  else
    [$3]=yes
  fi
else
  echo "configure: failed program was:" >&AC_FD_CC
  cat conftest.$ac_ext >&AC_FD_CC
  [$2]=no
fi
rm -fr conftest*])



dnl Test for GNU tar:
dnl
dnl AC_PROG_GNU_TAR()
AC_DEFUN(AC_PROG_GNU_TAR,
[AC_MSG_CHECKING([for GNU tar])
test -z "$GTAR" && GTAR=tar
if test -n "`$GTAR --version 2>/dev/null | grep GNU`"; then
  :
elif test -n "`gtar --version 2>/dev/null | grep GNU`"; then
  GTAR=gtar
else
  GTAR=no
fi
AC_MSG_RESULT($GTAR)
])

dnl Test for GNU make:
dnl
dnl AC_PROG_GNU_MAKE()
AC_DEFUN(AC_PROG_GNU_MAKE,
[AC_MSG_CHECKING([for GNU make])
test -z "$GMAKE" && GMAKE=make
if test -n "`$GMAKE --version 2>/dev/null | grep GNU`"; then
  :
elif test -n "`gmake --version 2>/dev/null | grep GNU`"; then
  GMAKE=gmake
else
  GMAKE=no
fi
AC_MSG_RESULT($GMAKE)
])

dnl Special macros:

dnl Test whether the C compiler as specified in the CompHEP settings 
dnl can compile and link a trivial C program.
dnl 
dnl AC_PROG_COMPHEP_CC_WORKS()
AC_DEFUN(AC_PROG_COMPHEP_CC_WORKS,
[AC_MSG_CHECKING([whether the C compiler selected by CompHEP works])
AC_LANG_SAVE
AC_LANG_COMPHEP_CC
AC_TRY_COMPILER([main(){return(0);}], ac_cv_prog_comphep_cc_works, ac_cv_prog_comphep_cc_cross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_comphep_cc_works)
if test $ac_cv_prog_comphep_cc_works = no; then
  AC_MSG_ERROR([installation or configuration problem: C compiler cannot create executables.
Check $comphepcom/CC if it is set up correctly])
fi
AC_MSG_CHECKING([whether this compiler is a cross-compiler])
AC_MSG_RESULT($ac_cv_prog_comphep_cc_cross)
cross_compiling=$ac_cv_prog_comphep_cc_cross
])

dnl Test whether the F77 compiler as specified in the CompHEP settings 
dnl can compile and link a trivial program.
dnl 
dnl AC_PROG_COMPHEP_F77_WORKS()
AC_DEFUN(AC_PROG_COMPHEP_F77_WORKS,
[AC_MSG_CHECKING([whether the Fortran77 compiler selected by CompHEP works])
AC_LANG_SAVE
AC_LANG_COMPHEP_F77
AC_TRY_COMPILER_NOINCLUDE(dnl
[      program conftest
      end
], ac_cv_prog_comphep_F77_works, ac_cv_prog_comphep_F77_cross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_comphep_F77_works)
if test $ac_cv_prog_comphep_F77_works = no; then
  AC_MSG_ERROR([installation or configuration problem: f77 compiler cannot create executables.
Check $comphepcom/F77 if it is set up correctly])
fi
AC_MSG_CHECKING([whether this compiler is a cross-compiler])
AC_MSG_RESULT($ac_cv_prog_comphep_F77_cross)
cross_compiling=$ac_cv_prog_comphep_F77_cross
])



dnl AC_LANG_COMPHEP_CC()
AC_DEFUN(AC_LANG_COMPHEP_CC,
[define([AC_LANG], [COMPHEP_CC])dnl
ac_ext=c
ac_compile='sh $comphepcom/CC conftest.$ac_ext 1>&AC_FD_CC'
ac_link='sh $comphepcom/CC -o conftest${ac_exeext} conftest.$ac_ext $LIBS 1>&AC_FD_CC'
cross_compiling=$ac_cv_prog_comphep_cc_cross
])


dnl AC_LANG_COMPHEP_F77()
AC_DEFUN(AC_LANG_COMPHEP_F77,
[define([AC_LANG], [COMPHEP_F77])dnl
ac_ext=f
ac_compile='sh $comphepcom/F77 conftest.$ac_ext 1>&AC_FD_CC'
ac_link='sh $comphepcom/F77 -o conftest${ac_exeext} conftest.$ac_ext $LIBS 1>&AC_FD_CC'
cross_compiling=$ac_cv_prog_comphep_F77_cross
])



dnl Check for the MPI Fortran 90 compiler. 
dnl Set the output variable `MPIF90' to the name of the compiler found.
dnl If no compiler found, set `MPIF90' to the value of `F90'
dnl 
dnl AC_PROG_MPIF90()
AC_DEFUN(AC_PROG_MPIF90,
[AC_BEFORE([$0], [AC_PROG_CPP])dnl
if test -z "$MPIF90"; then
  AC_PATH_PROGS(MPIF90, mpif95 mpif90)
  test -z "$MPIF90" && AC_MSG_WARN([*** No MPI Fortran 90 compiler found in \$PATH.
Parallel version won't be available.])
fi
if test -n "$MPIF90"; then
  AC_PROG_MPIF90_WORKS
else
  MPIF90=$F90
fi
])

dnl Test whether the MPI Fortran 90 compiler can compile and link a trivial
dnl Fortran program.  Also, test whether the Fortran 90 compiler is a
dnl cross-compiler.
dnl 
dnl AC_PROG_MPIF90_WORKS()
AC_DEFUN(AC_PROG_MPIF90_WORKS,
[AC_MSG_CHECKING([whether the MPI Fortran 90 compiler ($MPIF90 $F90FLAGS $LDFLAGS) works])
AC_LANG_SAVE
AC_LANG_FORTRAN90
AC_TRY_COMPILER_NOINCLUDE(dnl
[program conftest
end program conftest
], ac_cv_prog_mpif90_works, ac_cv_prog_mpif90_cross)
AC_LANG_RESTORE
AC_MSG_RESULT($ac_cv_prog_mpif90_works)

if test $ac_cv_prog_f90_works = no; then
  AC_MSG_ERROR([installation or configuration problem: MPI Fortran 90 compiler cannot create executables.])
fi
])


dnl *** This is probably obsolete:
dnl Check for the f77 runtime library.  This may be needed for linking 
dnl f90 programs with f77 libraries, at least on gcc-based Linux.
dnl We use the LD_LIBRARY_PATH.  Since we are on Linux,
dnl we may try also to find it with 'locate'.
dnl The path part of the result is stored in F77_LIBDIR
dnl If it is not found, return 'no'.  If we are not on Linux, leave this empty.
dnl
dnl AC_CHECK_F77_RUNTIME_LIBRARY()
AC_DEFUN(AC_CHECK_F77_RUNTIME_LIBRARY,
[if test "`uname`" = "Linux"
then
AC_CHECK_PROG(LOCATE,locate,yes)
if test "$LOCATE" = "yes"
then
LD_LIBRARY_PATH=`locate libg2c.a | sed -e 's!/libg2c.a!!' | xargs echo | sed -e 's/ /:/g'`:$LD_LIBRARY_PATH
fi
AC_PATH_PROG(F77_RUNTIME_LIBRARY, libg2c.a, no, $LD_LIBRARY_PATH)
F77_LIBDIR=`echo $F77_RUNTIME_LIBRARY | sed -e s!/libg2c.a!!`
AC_SUBST(F77_LIBDIR)
fi
])


dnl Test whether Metapost works and can dump a .mem file
dnl
dnl AC_PROG_MPOST_WORKS()
AC_DEFUN(AC_PROG_MPOST_WORKS,
[AC_MSG_CHECKING([whether Metapost ($MPOST) works])
touch conftest.mp
echo dump | $MPOST --ini conftest >/dev/null 2>&1
if test -f conftest.mem; then
  ac_cv_prog_mpost_works="yes"
else
  ac_cv_prog_mpost_works="no"
fi
AC_MSG_RESULT($ac_cv_prog_mpost_works)
rm -f conftest.mp conftest.mem conftest.log

if test $ac_cv_prog_mpost_works = "no"; then
  AC_MSG_ERROR([installation or configuration problem: METAPOST cannot create .mem files.])
fi
])

